<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.pkexec.deepin-diskmanager!message" line="0"/>
			<source>Authentication is required to read disk information</source>
			<translation>Аутентификация необходима для чтения информации с диска</translation>
		</message>
		<message>
			<location filename="com.deepin.pkexec.deepin-diskmanager!description" line="0"/>
			<source>Run Disk Manager Need Authentication</source>
			<translation>Для запуская диспетчера дисков требуется аутентификация</translation>
		</message>
	</context>
</TS>